range_chunks_aligned

Function range_chunks_aligned 

fn range_chunks_aligned<R>(
    range: R,
    alignment: usize,
) -> impl Iterator<Item = Range<usize>>
where R: RangeBounds<usize>,
Break a range into fixed-alignment chunks.

Each chunk is of size alignment, and starts on a multiple of alignment, with the possible exception of the first chunk (which may be misaligned and small) and the last (which may be small).